package test;

public interface Component5
{

    public String printOld();

}
